@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class AppAdminConfig(AppConfig):
-    name = 'app_admin'
+    name = 'localcosmos_server.app_admin'
