@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DatasetsConfig(AppConfig):
-    name = 'datasets'
+    name = 'localcosmos_server.datasets'
