@@ -34,6 +34,7 @@ OBSERVATION_FORM_SCHEMA = {
             "items" : {
                 "oneOf": [
                     { "$ref": "#/$defs/TaxonField" },
+                    { "$ref": "#/$defs/SelectTaxonField" },
                     { "$ref": "#/$defs/PointJSONField" },
                     { "$ref": "#/$defs/GeoJSONField" },
                     { "$ref": "#/$defs/DecimalField" },
@@ -162,7 +163,40 @@ OBSERVATION_FORM_SCHEMA = {
                     "properties": {
                         "widget": {
                             "type": "string",
-                            "enum": ["BackboneTaxonAutocompleteWidget"]
+                            "enum": ["BackboneTaxonAutocompleteWidget", "FixedTaxonWidget"]
+                        }
+                    },
+                    "required" : ["widget", "label"]
+                },
+                "widgetAttrs": {
+                    "type": "object"
+                },
+            },
+            "required": ["uuid", "fieldClass", "version", "role", "definition", "position"]
+        },
+        "SelectTaxonField": {
+            "type": "object",
+            "allOf": [
+                { "$ref": "#/$defs/FieldBase"}
+            ],
+            "properties": {
+                "fieldClass": {
+                    "type": "string",
+                    "enum": ["SelectTaxonField"]
+                },
+                "role": {
+                    "type": "string",
+                    "enum": ["taxonomicReference", "regular"]
+                },
+                "definition" : {
+                    "type": "object",
+                    "allOf" : [
+                        { "$ref": "#/$defs/FieldDefinitionBase" }
+                    ],
+                    "properties": {
+                        "widget": {
+                            "type": "string",
+                            "enum": ["SelectTaxonWidget"]
                         }
                     },
                     "required" : ["widget", "label"]
@@ -749,4 +783,36 @@ TAXON_JSON_SCHEMA = {
     },
     "required": ["taxonSource", "taxonLatname", "taxonNuid", "nameUuid"],
     "additionalProperties": False
+}
+
+DATASET_FILTERS_SCHEMA = {
+    "$schema": "https://json-schema.org/draft/2020-12/schema",
+    "$id": "https://localcosmos.org/datasetfilter.schema.json",
+    "title": "Dataset filters",
+    "description": "A list of filters for filtering datasets",
+    "type": "array",
+    "items": {
+            "$ref": "#/$defs/datasetFilter"
+        },
+    "additionalProperties": False,
+    "$defs": {
+        "datasetFilter": {
+            "type": "object",
+            "properties": {
+                "column": {
+                    "type": "string",
+                    "enum": ["name_uuid", "taxon_latname", "taxon_author", "taxon_nuid"]
+                },
+                "value": {
+                    "type": "string"
+                },
+                "operator": {
+                    "type": "string",
+                    "enum" : ["=", "!=", "startswith"]
+                },
+            },
+            "required": ["column", "value", "operator"],
+            "additionalProperties": False
+        }
+    }
 }
\ No newline at end of file
