@@ -1,7 +1,7 @@
 # putting these forms in .forms.py creates a circular import
 from django.conf import settings
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.auth import get_user_model
 
 '''
@@ -18,8 +18,8 @@ class SetupSuperuserForm(UserCreationForm):
         'email_mismatch': _("The two email address fields didn't match."),
     }
     
-    email = forms.EmailField(label=_('e-mail'))
-    email2 = forms.EmailField(label = _('e-mail (again)'))
+    email = forms.EmailField(label=_('Email'))
+    email2 = forms.EmailField(label = _('Email (again)'))
 
     def clean_email2(self):
         email = self.cleaned_data.get('email')
