@@ -8,6 +8,11 @@ SUPPORTED_LAZY_TAXONOMY_SOURCES = []
 if hasattr(settings, 'LAZY_TAXONOMY_SOURCES'):
     SUPPORTED_LAZY_TAXONOMY_SOURCES = [db[0] for db in settings.LAZY_TAXONOMY_SOURCES]
 
+
+TAXON_SOURCE_VERBOSE_NAME_MAP = {
+    'taxonomy.sources.col' : 'Catalogue of Life',
+    'taxonomy.sources.custom' : 'Custom Taxonomy',
+}
 ##################################################################################################################
 #
 # LazyTaxon
@@ -25,6 +30,7 @@ class LazyTaxonBase:
     def __init__(self, *args, **kwargs):
 
         self.instance = None # either ModelwithTaxon Subclass or a TaxonTree Subclass
+        self.origin = None # class name of the instance passed
 
         if 'instance' in kwargs:
 
@@ -57,6 +63,15 @@ class LazyTaxonBase:
             self.taxon_nuid = kwargs['taxon_nuid']
             self.name_uuid = kwargs['name_uuid']
 
+        elif 'taxonLatname' in kwargs and 'taxonAuthor' in kwargs and 'taxonSource' in kwargs and 'taxonNuid' in kwargs and 'nameUuid' in kwargs:
+            self.taxon_latname = kwargs['taxonLatname']
+            self.taxon_author = kwargs['taxonAuthor']
+            self.taxon_source = kwargs['taxonSource']
+            self.taxon_include_descendants = kwargs.get('taxonIncludeDescendants', False)
+
+            self.taxon_nuid = kwargs['taxonNuid']
+            self.name_uuid = kwargs['nameUuid']
+
         else:
             raise ValueError('Unable to instantiate LazyTaxon, improper parameters given: %s' %kwargs)
 
@@ -120,7 +135,9 @@ class LazyTaxonBase:
     def as_typeahead_choice(self, label=None):
 
         if label is None:
-            label = self.taxon_latname
+            label = '{0} {1}'.format(self.taxon_latname, self.taxon_author or '')
+        
+        verbose_taxon_source_name = TAXON_SOURCE_VERBOSE_NAME_MAP.get(self.taxon_source, None)
         
         obj = {
             'label': label,
@@ -129,6 +146,7 @@ class LazyTaxonBase:
             'taxon_nuid': self.taxon_nuid,
             'taxon_source' : self.taxon_source,
             'name_uuid': str(self.name_uuid),
+            'verbose_taxon_source_name': verbose_taxon_source_name,
         }
         return obj
 
@@ -160,6 +178,9 @@ class LazyTaxonBase:
 
     # default str output
     def __str__(self):
+        if self.taxon_author:
+            return '{0} {1}'.format(self.taxon_latname, self.taxon_author)
+        
         return self.taxon_latname
 
     def __eq__(self, other):
