@@ -10,6 +10,8 @@ class AppMixin:
 
         self.app = App.objects.get(uid=kwargs['app_uid'])
         
+        request.app = self.app
+        
         return super().dispatch(request, *args, **kwargs)
 
 
@@ -194,10 +196,18 @@ class ContentImageViewMixin(LicencingFormViewMixin):
 
         requires_translation = form.cleaned_data.get('requires_translation', False)
         self.content_image.requires_translation = requires_translation
+        
+        self.content_image.is_primary = form.cleaned_data.get('is_primary', False)
 
         # there might be text
-        if form.cleaned_data.get('text', None):
-            self.content_image.text = form.cleaned_data['text']
+        caption = form.cleaned_data.get('text', None)
+        self.content_image.text = caption
+            
+        # SEO stuff
+        title = form.cleaned_data.get('title', None)
+        self.content_image.title = title
+        alt_text = form.cleaned_data.get('alt_text', None)
+        self.content_image.alt_text = alt_text
         
         self.content_image.save()
 
@@ -228,7 +238,10 @@ class ContentImageViewMixin(LicencingFormViewMixin):
             initial['source_image'] = self.content_image.image_store.source_image
             initial['image_type'] = self.content_image.image_type
             initial['text'] = self.content_image.text
+            initial['title'] = self.content_image.title
+            initial['alt_text'] = self.content_image.alt_text
             initial['requires_translation'] = self.content_image.requires_translation
+            initial['is_primary'] = self.content_image.is_primary
 
             licencing_initial = self.get_licencing_initial()
             initial.update(licencing_initial)
